@@ -186,9 +186,9 @@ def request_traderjoe_data():
     #    final_df[['USDC.E_liquidity', 'USDC.E', 'USDCE_apy']].copy()
     #    final_df[['USDT.E_liquidity','USDT.E', 'USDTE_apy']].copy()
 
-    traderjoe_usdc_df = traderjoe_usdc_df.rename(columns={'USDC_liquidity': 'supply_liquidity', 'USDC_apy': 'dapr'})
-    traderjoe_usdt_df = traderjoe_usdt_df.rename(columns={'USDT_liquidity': 'supply_liquidity', 'USDT_apy': 'dapr'})
-    traderjoe_btcb_df = traderjoe_btcb_df.rename(columns={'BTC.B_liquidity': 'supply_liquidity', 'BTCB_apy': 'dapr'})
+    traderjoe_usdc_df = traderjoe_usdc_df.rename(columns={'USDC_liquidity': 'supply_liquidity', 'USDC_apy': 'apy'})
+    traderjoe_usdt_df = traderjoe_usdt_df.rename(columns={'USDT_liquidity': 'supply_liquidity', 'USDT_apy': 'apy'})
+    traderjoe_btcb_df = traderjoe_btcb_df.rename(columns={'BTC.B_liquidity': 'supply_liquidity', 'BTCB_apy': 'apy'})
     return traderjoe_usdc_df, traderjoe_usdt_df, traderjoe_btcb_df
 
 
